Frame class abstract

Base class for all UDX frames.

Implementers

Constructors

Frame(FrameType type)

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
Calculate the length of the serialized frame.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FrameType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Serialize the frame into a byte list.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) → Frame
A factory constructor to deserialize a frame from bytes.