MaxDataFrame class

MAX_DATA Frame (Type 0x05) Informs the peer of the maximum amount of data that can be sent on the connection.

Inheritance

Constructors

MaxDataFrame({required int maxData})

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
Calculate the length of the serialized frame.
no setteroverride
maxData → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Serialize the frame into a byte list.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) → MaxDataFrame
A factory constructor to deserialize a frame from bytes.
override