PathResponseFrame class

PATH_RESPONSE Frame (Type 0x0a) Used to respond to a PATH_CHALLENGE. Must contain the exact same data as the challenge frame it is responding to.

Inheritance

Constructors

PathResponseFrame({required Uint8List data})

Properties

data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
Calculate the length of the serialized frame.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Serialize the frame into a byte list.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) → PathResponseFrame
A factory constructor to deserialize a frame from bytes.
override