RetireConnectionIdFrame class

RETIRE_CONNECTION_ID Frame (Type 0x11) Indicates that the endpoint will no longer use a Connection ID that was issued by the peer. This also serves as a request for the peer to send a new Connection ID.

Inheritance

Constructors

RetireConnectionIdFrame({required int sequenceNumber})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Calculate the length of the serialized frame.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int
final
type FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serialize the frame into a byte list.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) RetireConnectionIdFrame
A factory constructor to deserialize a frame from bytes.
override