StreamFrame class

STREAM Frame (Type 0x03) Carries data for a specific stream.

Inheritance

Constructors

StreamFrame({bool isFin = false, bool isSyn = false, int offset = 0, required Uint8List data})

Properties

data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
isFin → bool
final
isSyn → bool
final
length → int
Calculate the length of the serialized frame.
no setteroverride
offset → int
Position of data within this stream's own byte sequence.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Serialize the frame into a byte list.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) → StreamFrame
A factory constructor to deserialize a frame from bytes.
override

Constants

headerLength → const int
Type (1) + Flags (1) + Offset (8) + Length (2) + Data (variable)