UdxErrorCode class

UDX error codes for CONNECTION_CLOSE and RESET_STREAM frames

Constructors

UdxErrorCode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

connectionTimeout → const int
Connection timeout
flowControlError → const int
Flow control error
internalError → const int
Internal error
invalidMigration → const int
Invalid connection migration
noError → const int
No error (graceful close)
protocolViolation → const int
Protocol violation
streamLimitError → const int
Stream limit exceeded