UdxLogger typedef

UdxLogger = void Function(String level, String message)

Logging infrastructure for dart-udx

Provides a configurable logging system to replace direct print statements. Applications can set a custom logger and control verbosity. Type definition for a logger function

Implementation

/// Type definition for a logger function
typedef UdxLogger = void Function(String level, String message);