UdxMetricsObserver class abstract

Observer interface for UDX metrics and events.

This interface allows external systems to observe low-level UDX transport events such as handshakes, retransmissions, congestion control changes, and flow control events.

Constructors

UdxMetricsObserver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCongestionWindowUpdate(ConnectionId cid, int oldCwnd, int newCwnd, String reason) → void
Called when the congestion window is updated.
onFlowControlBlocked(ConnectionId cid, int streamId, int pendingBytes, int windowSize) → void
Called when flow control blocks sending on a stream.
onHandshakeComplete(ConnectionId localCid, Duration duration, bool success, String? error) → void
Called when a UDX handshake completes (success or failure).
onHandshakeStart(ConnectionId localCid, ConnectionId remoteCid, String remoteAddr) → void
Called when a UDX handshake begins.
onPacketLoss(ConnectionId cid, int seq, String lossType) → void
Called when packet loss is detected.
onPacketRetransmit(ConnectionId cid, int seq, int attemptCount, Duration rto) → void
Called when a packet is retransmitted.
onPathMigrationComplete(ConnectionId cid, bool success) → void
Called when path migration completes.
onPathMigrationStart(ConnectionId cid, String oldAddr, String newAddr) → void
Called when path migration starts (address change detected).
onRttSample(ConnectionId cid, Duration rtt, Duration smoothedRtt, Duration rttVar) → void
Called when a new RTT sample is calculated.
onStreamClosed(ConnectionId cid, int streamId, Duration duration, int bytesRead, int bytesWritten) → void
Called when a UDX stream is closed.
onStreamCreated(ConnectionId cid, int streamId, bool isInitiator) → void
Called when a new UDX stream is created.
onStreamLimitExceeded(ConnectionId cid, int currentCount, int limit) → void
Called when an attempt to create a stream fails because the limit is exceeded.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited