onFlowControlBlocked abstract method

void onFlowControlBlocked(
  1. ConnectionId cid,
  2. int streamId,
  3. int pendingBytes,
  4. int windowSize,
)

Called when flow control blocks sending on a stream.

cid is the connection ID. streamId is the stream ID that was blocked. pendingBytes is the number of bytes waiting to be sent. windowSize is the current flow control window size.

Implementation

void onFlowControlBlocked(ConnectionId cid, int streamId, int pendingBytes, int windowSize);