onStreamClosed abstract method
void
onStreamClosed(
- ConnectionId cid,
- int streamId,
- Duration duration,
- int bytesRead,
- int bytesWritten,
Called when a UDX stream is closed.
cid is the connection ID.
streamId is the stream ID.
duration is how long the stream was open.
bytesRead is the total bytes read from the stream.
bytesWritten is the total bytes written to the stream.
Implementation
void onStreamClosed(ConnectionId cid, int streamId, Duration duration, int bytesRead, int bytesWritten);