UdxVersion class

UDX protocol version constants

Constructors

UdxVersion()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isSupported(int version) → bool
Checks if a version is supported
negotiateVersion(List<int> clientVersions) → int?
Finds the highest common version between client and server

Constants

current → const int
The current version used by this implementation
supportedVersions → const List<int>
List of all supported versions (in preference order).
v1 → const int
Version 1 - Original implementation with fixed 8-byte CIDs
v2 → const int
Version 2 - Variable-length CIDs, enhanced QUIC compliance
v3 → const int
Version 3 - STREAM frames carry a byte offset, and are reassembled per stream rather than in connection sequence order.