AckFrame class
ACK Frame (Type 0x02) Acknowledges one or more packet ranges. Based on QUIC ACK Frame (RFC 9000, Section 19.3). Includes optional ECN counts for Explicit Congestion Notification.
Constructors
Properties
- ackDelay → int
-
final
-
ackRanges
→ List<
AckRange> -
final
- ceCount → int?
-
final
- ect0Count → int?
-
final
- ect1Count → int?
-
final
- firstAckRangeLength → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- largestAcked → int
-
final
- length → int
-
Calculate the length of the serialized frame.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → FrameType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
Serialize the frame into a byte list.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited