ConnectionId class
Represents a UDX Connection Identifier (CID).
CIDs are used to identify a UDX connection independently of the underlying network path (IP address and port).
Per QUIC specification, CIDs can be 0-20 bytes in length.
Constructors
-
ConnectionId(List<
int> bytes) - Creates a ConnectionId from a list of bytes.
- ConnectionId.fromUint8List(Uint8List _bytes)
- Creates a ConnectionId from a Uint8List.
- ConnectionId.random({int length = defaultCidLength})
-
Generates a new random ConnectionId with the default length.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- defaultCidLength → const int
- The default length for generated CIDs (for backward compatibility).
- maxCidLength → const int
- The maximum length of a CID in bytes.
- minCidLength → const int
- The minimum length of a CID in bytes.