DataBlockedFrame class
DATA_BLOCKED Frame (Type 0x0e) Indicates that the connection is blocked due to connection-level flow control. Sent when the sender wants to send data but is blocked by the connection-level MAX_DATA limit.
Constructors
- DataBlockedFrame({required int maxData})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
Serialize the frame into a byte list.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromBytes(
ByteData view, int offset) → DataBlockedFrame -
A factory constructor to deserialize a frame from bytes.
override