NewConnectionIdFrame class

NEW_CONNECTION_ID Frame (Type 0x10) Provides the peer with a new Connection ID that can be used for this connection. This enables connection migration and prevents linkability attacks.

Inheritance

Constructors

NewConnectionIdFrame({required int sequenceNumber, required int retirePriorTo, required ConnectionId connectionId, required StatelessResetToken resetToken})

Properties

connectionId ConnectionId
final
hashCode int
The hash code for this object.
no setterinherited
length int
Calculate the length of the serialized frame.
no setteroverride
resetToken StatelessResetToken
final
retirePriorTo int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int
final
type FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serialize the frame into a byte list.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) NewConnectionIdFrame
A factory constructor to deserialize a frame from bytes.
override