StopSendingFrame class

STOP_SENDING Frame (Type 0x0d) Signals that the endpoint no longer wishes to receive data on a stream. The peer should close the write side of the stream in response.

Inheritance

Constructors

StopSendingFrame({required int streamId, required int errorCode})

Properties

errorCode int
final
hashCode int
The hash code for this object.
no setterinherited
length int
Calculate the length of the serialized frame.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId int
final
type FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serialize the frame into a byte list.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) StopSendingFrame
A factory constructor to deserialize a frame from bytes.
override