StreamDataBlockedFrame class

STREAM_DATA_BLOCKED Frame (Type 0x0f) Indicates that a stream is blocked due to stream-level flow control. Sent when the sender wants to send data on a stream but is blocked by the stream-level flow control limit.

Inheritance

Constructors

StreamDataBlockedFrame({required int streamId, required int maxStreamData})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Calculate the length of the serialized frame.
no setteroverride
maxStreamData int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId int
final
type FrameType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serialize the frame into a byte list.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(ByteData view, int offset) StreamDataBlockedFrame
A factory constructor to deserialize a frame from bytes.
override