retransmitCount property
How many times this packet has been retransmitted, and when it last was. Used to space attempts and to collapse a near-simultaneous RTO timer and fast-retransmit into a single re-send.
Implementation
int retransmitCount = 0;
How many times this packet has been retransmitted, and when it last was. Used to space attempts and to collapse a near-simultaneous RTO timer and fast-retransmit into a single re-send.
int retransmitCount = 0;