UdxLogging class
Centralized logging for dart-udx
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
debug(
String message) → void - Log a debug message (only if verbose is true)
-
error(
String message) → void - Log an error message (always logged if logger is set)
-
infoLog(
String message) → void - Log an info message (only if info is true)
-
setDefaultLogger(
) → void - Set a simple print-based logger
-
warn(
String message) → void - Log a warning message (always logged if logger is set)